Prometheus postgres_exporter
============================

.. currentmodule:: pglift.prometheus

Module :mod:`pglift.prometheus` exposes the following API functions for
monitoring management using `Prometheus postgres_exporter`_:

.. autofunction:: available
.. autofunction:: apply
.. autofunction:: start
.. autofunction:: stop

.. autoclass:: PostgresExporter

.. _`Prometheus postgres_exporter`: https://github.com/prometheus-community/postgres_exporter
